==> glue-1.93.0-sources.jar: software/amazon/awscdk/services/glue/CfnSchemaVersionProps.java <==
package software.amazon.awscdk.services.glue;

/**
 * Properties for defining a `AWS::Glue::SchemaVersion`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:44.462Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.glue.$Module.class, fqn = "@aws-cdk/aws-glue.CfnSchemaVersionProps")
@software.amazon.jsii.Jsii.Proxy(CfnSchemaVersionProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnSchemaVersionProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::Glue::SchemaVersion.Schema`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object getSchema();

    /**
     * `AWS::Glue::SchemaVersion.SchemaDefinition`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getSchemaDefinition();

    /**
     * @return a {@link Builder} of {@link CfnSchemaVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnSchemaVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnSchemaVersionProps> {
        private java.lang.Object schema;
        private java.lang.String schemaDefinition;

        /**
         * Sets the value of {@link CfnSchemaVersionProps#getSchema}
         * @param schema `AWS::Glue::SchemaVersion.Schema`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder schema(software.amazon.awscdk.core.IResolvable schema) {
            this.schema = schema;
            return this;
        }

        /**
         * Sets the value of {@link CfnSchemaVersionProps#getSchema}
         * @param schema `AWS::Glue::SchemaVersion.Schema`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder schema(software.amazon.awscdk.services.glue.CfnSchemaVersion.SchemaProperty schema) {
            this.schema = schema;
            return this;
        }

        /**
         * Sets the value of {@link CfnSchemaVersionProps#getSchemaDefinition}
         * @param schemaDefinition `AWS::Glue::SchemaVersion.SchemaDefinition`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder schemaDefinition(java.lang.String schemaDefinition) {
            this.schemaDefinition = schemaDefinition;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnSchemaVersionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnSchemaVersionProps build() {
            return new Jsii$Proxy(schema, schemaDefinition);
        }
    }

    /**
     * An implementation for {@link CfnSchemaVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnSchemaVersionProps {
        private final java.lang.Object schema;
        private final java.lang.String schemaDefinition;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.schema = software.amazon.jsii.Kernel.get(this, "schema", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.schemaDefinition = software.amazon.jsii.Kernel.get(this, "schemaDefinition", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.Object schema, final java.lang.String schemaDefinition) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.schema = java.util.Objects.requireNonNull(schema, "schema is required");
            this.schemaDefinition = java.util.Objects.requireNonNull(schemaDefinition, "schemaDefinition is required");
        }

        @Override
        public final java.lang.Object getSchema() {
            return this.schema;
        }

        @Override
        public final java.lang.String getSchemaDefinition() {
            return this.schemaDefinition;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("schema", om.valueToTree(this.getSchema()));
            data.set("schemaDefinition", om.valueToTree(this.getSchemaDefinition()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-glue.CfnSchemaVersionProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnSchemaVersionProps.Jsii$Proxy that = (CfnSchemaVersionProps.Jsii$Proxy) o;

            if (!schema.equals(that.schema)) return false;
            return this.schemaDefinition.equals(that.schemaDefinition);
        }

        @Override
        public final int hashCode() {
            int result = this.schema.hashCode();
            result = 31 * result + (this.schemaDefinition.hashCode());
            return result;
        }
    }
}

==> glue-1.182.0-sources.jar: software/amazon/awscdk/services/glue/CfnSchemaVersionProps.java <==
package software.amazon.awscdk.services.glue;

/**
 * Properties for defining a `CfnSchemaVersion`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.glue.*;
 * CfnSchemaVersionProps cfnSchemaVersionProps = CfnSchemaVersionProps.builder()
 *         .schema(SchemaProperty.builder()
 *                 .registryName("registryName")
 *                 .schemaArn("schemaArn")
 *                 .schemaName("schemaName")
 *                 .build())
 *         .schemaDefinition("schemaDefinition")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:43.385Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.glue.$Module.class, fqn = "@aws-cdk/aws-glue.CfnSchemaVersionProps")
@software.amazon.jsii.Jsii.Proxy(CfnSchemaVersionProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnSchemaVersionProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The schema that includes the schema version.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object getSchema();

    /**
     * The schema definition for the schema version.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getSchemaDefinition();

    /**
     * @return a {@link Builder} of {@link CfnSchemaVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnSchemaVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnSchemaVersionProps> {
        java.lang.Object schema;
        java.lang.String schemaDefinition;

        /**
         * Sets the value of {@link CfnSchemaVersionProps#getSchema}
         * @param schema The schema that includes the schema version. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder schema(software.amazon.awscdk.core.IResolvable schema) {
            this.schema = schema;
            return this;
        }

        /**
         * Sets the value of {@link CfnSchemaVersionProps#getSchema}
         * @param schema The schema that includes the schema version. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder schema(software.amazon.awscdk.services.glue.CfnSchemaVersion.SchemaProperty schema) {
            this.schema = schema;
            return this;
        }

        /**
         * Sets the value of {@link CfnSchemaVersionProps#getSchemaDefinition}
         * @param schemaDefinition The schema definition for the schema version. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder schemaDefinition(java.lang.String schemaDefinition) {
            this.schemaDefinition = schemaDefinition;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnSchemaVersionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnSchemaVersionProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnSchemaVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnSchemaVersionProps {
        private final java.lang.Object schema;
        private final java.lang.String schemaDefinition;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.schema = software.amazon.jsii.Kernel.get(this, "schema", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.schemaDefinition = software.amazon.jsii.Kernel.get(this, "schemaDefinition", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.schema = java.util.Objects.requireNonNull(builder.schema, "schema is required");
            this.schemaDefinition = java.util.Objects.requireNonNull(builder.schemaDefinition, "schemaDefinition is required");
        }

        @Override
        public final java.lang.Object getSchema() {
            return this.schema;
        }

        @Override
        public final java.lang.String getSchemaDefinition() {
            return this.schemaDefinition;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("schema", om.valueToTree(this.getSchema()));
            data.set("schemaDefinition", om.valueToTree(this.getSchemaDefinition()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-glue.CfnSchemaVersionProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnSchemaVersionProps.Jsii$Proxy that = (CfnSchemaVersionProps.Jsii$Proxy) o;

            if (!schema.equals(that.schema)) return false;
            return this.schemaDefinition.equals(that.schemaDefinition);
        }

        @Override
        public final int hashCode() {
            int result = this.schema.hashCode();
            result = 31 * result + (this.schemaDefinition.hashCode());
            return result;
        }
    }
}
